<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Imports\EmailImport;
use Illuminate\Support\Facades\Mail;
use App\Mail\SendEmail;
use Illuminate\Support\Facades\Storage; // Import Storage facade
use Maatwebsite\Excel\Facades\Excel;

class EmailController extends Controller
{
    public function showImportForm()
    {
        return view('import');
    }

    public function import(Request $request)
    {
        $request->validate([
            'file' => 'required|mimes:xlsx,xls',
        ]);

        $file = $request->file('file');
        $fileName = $file->getClientOriginalName(); // Get the original file name
        
        // Store the file in storage/app/uploads directory
        $filePath = $file->storeAs('uploads', $fileName);

        $import = new EmailImport();
        Excel::import($import, $filePath); // Import emails from the uploaded file

        $emails = $import->getEmails();
        foreach ($emails as $email) {
            Mail::to($email)->send(new SendEmail());
            $sentEmails[] = $email; 
        }

        return response()->json(['emails' => $emails], 200);
    }

    public function sendEmails()
    {
        // Get the path of the last uploaded file
        $latestFile = Storage::files('uploads')[0];

        $import = new EmailImport();
        Excel::import($import, $latestFile); // Import emails from the last uploaded file

        $emails = $import->getEmails();
        
        $successCount = 0;
        $failureCount = 0;
        $sentEmails = [];
        
        foreach ($emails as $email) {
            Mail::to($email)->send(new SendEmail());
            $successCount++;
            $sentEmails[] = $email; 
        }

        return "Emails sent successfully: $successCount. Failed to send: $failureCount.";
    }
}
